@@ -1,8 +1,5 @@
 package Dist::Zilla::Plugin::GitHub;
-{
-  $Dist::Zilla::Plugin::GitHub::VERSION = '0.36';
-}
-
+$Dist::Zilla::Plugin::GitHub::VERSION = '0.37';
 use strict;
 use warnings;
 
@@ -30,13 +27,19 @@ has 'api'  => (
 	default => 'https://api.github.com'
 );
 
+has 'prompt_2fa' => (
+	is  => 'rw',
+	isa => 'Bool',
+	default => 0
+);
+
 =head1 NAME
 
 Dist::Zilla::Plugin::GitHub - Plugins to integrate Dist::Zilla with GitHub
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =head1 DESCRIPTION
 
@@ -64,7 +67,7 @@ bundle|Dist::Zilla::PluginBundle::GitHub>.
 sub _get_credentials {
 	my ($self, $nopass) = @_;
 
-	my ($login, $pass, $token);
+	my ($login, $pass, $token, $otp);
 
 	my %identity = Config::Identity::GitHub -> load
 		if try_load_class('Config::Identity::GitHub');
@@ -91,27 +94,30 @@ sub _get_credentials {
 		} else {
 			$token = `git config github.token`;    chomp $token;
 			$pass  = `git config github.password`; chomp $pass;
+
+			# modern "tokens" can be used as passwords with basic auth, so...
+			# see https://help.github.com/articles/creating-an-access-token-for-command-line-use
+			$pass ||= $token if $token;
 		}
 
-		if ($token) {
-			$self -> log("Err: Login with GitHub token is deprecated");
-			return (undef, undef);
-		} elsif (!$pass) {
-			require Term::ReadKey;
+		$self -> log("Err: Login with GitHub token is deprecated")
+			if $token && !$pass;
 
-			Term::ReadKey::ReadMode('noecho');
-			$pass = $self -> zilla -> chrome
-					-> term_ui -> get_reply(
-				prompt => "GitHub password for '$login'",
-				allow  => sub {
-					defined $_[0] and length $_[0]
-				});
-			Term::ReadKey::ReadMode('normal');
-			print "\n";
+		if (!$pass) {
+			$pass = $self -> zilla -> chrome -> prompt_str(
+				"GitHub password for '$login'", { noecho => 1 },
+			);
+		}
+
+		if ($self -> prompt_2fa) {
+			$otp = $self -> zilla -> chrome -> prompt_str(
+				"GitHub two-factor authentication code for '$login'",
+				{ noecho => 1 },
+			);
 		}
 	}
 
-	return ($login, $pass);
+	return ($login, $pass, $otp);
 }
 
 sub _get_repo_name {
@@ -146,14 +152,19 @@ sub _check_response {
 		my $json_text = from_json $response -> {'content'};
 
 		if (!$response -> {'success'}) {
+			return 'redo' if (($response -> {'status'} eq '401') and
+			                  ($response -> {'headers'} ->
+			                     {'x-github-otp'} =~ /^required/));
+
 			$self -> log("Err: ", $json_text -> {'message'});
 			return;
 		}
 
 		return $json_text;
 	} catch {
-		if ($response and !$response -> {'success'} and $response -> {'status'} eq '599') {
-		    #possibly HTTP::Tiny error
+		if ($response and !$response -> {'success'} and
+		    $response -> {'status'} eq '599') {
+			#possibly HTTP::Tiny error
 			$self -> log("Err: ", $response -> {'content'});
 			return;
 		}
