@@ -1,8 +1,5 @@
 package Dist::Zilla::Plugin::GitHub::Create;
-{
-  $Dist::Zilla::Plugin::GitHub::Create::VERSION = '0.36';
-}
-
+$Dist::Zilla::Plugin::GitHub::Create::VERSION = '0.37';
 use strict;
 use warnings;
 
@@ -17,34 +14,39 @@ extends 'Dist::Zilla::Plugin::GitHub';
 with 'Dist::Zilla::Role::AfterMint';
 with 'Dist::Zilla::Role::TextTemplate';
 
+has 'org' => (
+	is      => 'ro',
+	isa     => 'Maybe[Str]'
+);
+
 has 'public' => (
-	is	=> 'ro',
-	isa	=> 'Bool',
-	default	=> 1
+	is      => 'ro',
+	isa     => 'Bool',
+	default => 1
 );
 
 has 'prompt' => (
-	is	=> 'ro',
-	isa	=> 'Bool',
-	default	=> 0
+	is      => 'ro',
+	isa     => 'Bool',
+	default => 0
 );
 
 has 'has_issues' => (
-	is	=> 'ro',
-	isa	=> 'Bool',
-	default	=> 1
+	is      => 'ro',
+	isa     => 'Bool',
+	default => 1
 );
 
 has 'has_wiki' => (
-	is	=> 'ro',
-	isa	=> 'Bool',
-	default	=> 1
+	is      => 'ro',
+	isa     => 'Bool',
+	default => 1
 );
 
 has 'has_downloads' => (
-	is	=> 'ro',
-	isa	=> 'Bool',
-	default	=> 1
+	is      => 'ro',
+	isa     => 'Bool',
+	default => 1
 );
 
 =head1 NAME
@@ -53,7 +55,7 @@ Dist::Zilla::Plugin::GitHub::Create - Create a new GitHub repo on dzil new
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -96,8 +98,8 @@ repository's private URL. See L</"ADDING REMOTE"> for more info.
 =cut
 
 sub after_mint {
-	my $self	= shift;
-	my ($opts)	= @_;
+	my $self   = shift;
+	my ($opts) = @_;
 
 	return if $self -> prompt and not $self -> _confirm;
 
@@ -115,7 +117,7 @@ sub after_mint {
 		$repo_name = $self -> zilla -> name;
 	}
 
-	my ($login, $pass)  = $self -> _get_credentials(0);
+	my ($login, $pass, $otp)  = $self -> _get_credentials(0);
 
 	my $http = HTTP::Tiny -> new;
 
@@ -128,18 +130,20 @@ sub after_mint {
 	$params -> {'description'} = $opts -> {'descr'} if $opts -> {'descr'};
 
 	$params -> {'has_issues'} = $self -> has_issues;
-	$self -> log([ 'Issues are %s', $params -> {'has_issues'}   ?
+	$self -> log([ 'Issues are %s', $params -> {'has_issues'} ?
 				'enabled' : 'disabled' ]);
 
 	$params -> {'has_wiki'} = $self -> has_wiki;
-	$self -> log([ 'Wiki is %s', $params -> {'has_wiki'}   ?
+	$self -> log([ 'Wiki is %s', $params -> {'has_wiki'} ?
 				'enabled' : 'disabled' ]);
 
 	$params -> {'has_downloads'} = $self -> has_downloads;
-	$self -> log([ 'Downloads are %s', $params -> {'has_downloads'}   ?
+	$self -> log([ 'Downloads are %s', $params -> {'has_downloads'} ?
 				'enabled' : 'disabled' ]);
 
-	my $url = $self -> api.'/user/repos';
+	my $url = $self -> api;
+	$url .= $self -> org ? '/orgs/' . $self -> org . '/' : '/user/';
+	$url .= 'repos';
 
 	if ($pass) {
 		require MIME::Base64;
@@ -148,6 +152,11 @@ sub after_mint {
 		$headers -> {'authorization'} = "Basic $basic";
 	}
 
+	if ($self -> prompt_2fa) {
+		$headers -> { 'X-GitHub-OTP' } = $otp;
+		$self -> log([ "Using two-factor authentication" ]);
+	}
+
 	$content = to_json $params;
 
 	my $response = $http -> request('POST', $url, {
@@ -156,6 +165,13 @@ sub after_mint {
 	});
 
 	my $repo = $self -> _check_response($response);
+
+	if ($repo eq 'redo') {
+		$self -> log("Retrying with two-factor authentication");
+		$self -> prompt_2fa(1);
+		$repo = $self -> after_mint($opts);
+	}
+
 	return if not $repo;
 
 	my $git_dir = "$root/.git";
@@ -206,6 +222,11 @@ will work:
 
     repo = {{ lc $dist -> name }}
 
+=item C<org>
+
+Specifies the name of a GitHub organization in which to create the repository
+(by default the repository is created in the user's account).
+
 =item C<prompt>
 
 Prompt for confirmation before creating a GitHub repository if this option is
@@ -234,6 +255,12 @@ Enable the wiki for the new repository if this option is set to true (default).
 
 Enable downloads for the new repository if this option is set to true (default).
 
+=item C<prompt_2fa>
+
+Prompt for GitHub two-factor authentication code if this option is set to true
+(default is false). If this option is set to false but GitHub requires 2fa for
+the login, it'll be automatically enabled.
+
 =back
 
 =head1 ADDING REMOTE
