@@ -1,8 +1,5 @@
 package Dist::Zilla::Plugin::GitHub::Update;
-{
-  $Dist::Zilla::Plugin::GitHub::Update::VERSION = '0.36';
-}
-
+$Dist::Zilla::Plugin::GitHub::Update::VERSION = '0.37';
 use strict;
 use warnings;
 
@@ -14,27 +11,27 @@ extends 'Dist::Zilla::Plugin::GitHub';
 with 'Dist::Zilla::Role::AfterRelease';
 
 has 'cpan' => (
-	is	=> 'ro',
-	isa	=> 'Bool',
-	default	=> 1
+	is      => 'ro',
+	isa     => 'Bool',
+	default => 1
 );
 
 has 'p3rl' => (
-	is	=> 'ro',
-	isa	=> 'Bool',
-	default	=> 0
+	is      => 'ro',
+	isa     => 'Bool',
+	default => 0
 );
 
 has 'metacpan' => (
-	is	=> 'ro',
-	isa	=> 'Bool',
-	default	=> 0
+	is      => 'ro',
+	isa     => 'Bool',
+	default => 0
 );
 
 has 'meta_home' => (
-	is	=> 'ro',
-	isa	=> 'Bool',
-	default	=> 0
+	is      => 'ro',
+	isa     => 'Bool',
+	default => 0
 );
 
 =head1 NAME
@@ -43,7 +40,7 @@ Dist::Zilla::Plugin::GitHub::Update - Update a GitHub repo's info on release
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -79,11 +76,11 @@ when C<dzil release> is run.
 =cut
 
 sub after_release {
-	my $self	= shift;
-	my ($opts)	= @_;
-	my $dist_name	= $self -> zilla -> name;
+	my $self      = shift;
+	my ($opts)    = @_;
+	my $dist_name = $self -> zilla -> name;
 
-	my ($login, $pass)  = $self -> _get_credentials(0);
+	my ($login, $pass, $otp)  = $self -> _get_credentials(0);
 	return if (!$login);
 
 	my $repo_name = $self -> _get_repo_name($login);
@@ -131,14 +128,26 @@ sub after_release {
 		$headers -> {'Authorization'} = "Basic $basic";
 	}
 
+	if ($self -> prompt_2fa) {
+		$headers -> { 'X-GitHub-OTP' } = $otp;
+		$self -> log([ "Using two-factor authentication" ]);
+	}
+
 	$content = to_json $params;
 
-	my $response	= $http -> request('PATCH', $url, {
+	my $response = $http -> request('PATCH', $url, {
 		content => $content,
 		headers => $headers
 	});
 
 	my $repo = $self -> _check_response($response);
+
+	if ($repo eq 'redo') {
+		$self -> log("Retrying with two-factor authentication");
+		$self -> prompt_2fa(1);
+		$repo = $self -> after_release(@$opts);
+	}
+
 	return if not $repo;
 }
 
@@ -190,6 +199,12 @@ false). If no value is present in the dist meta, this option is ignored.
 This takes precedence over the C<metacpan>, C<cpan> and C<p3rl> options (if all
 four are true, meta_home will be used).
 
+=item C<prompt_2fa>
+
+Prompt for GitHub two-factor authentication code if this option is set to true
+(default is false). If this option is set to false but GitHub requires 2fa for
+the login, it'll be automatically enabled.
+
 =back
 
 =head1 AUTHOR
